<?php

namespace XenGenTr\ResimliOneCikanKonular\Admin\Controller;

use XF\Mvc\ParameterBag;

class OneCikan extends \XF\Admin\Controller\AbstractController
{
	protected function preDispatchController($action, ParameterBag $params)
	{
		$this->assertAdminPermission('XGTOneCikanKonularAdmin');
	}
	
	public function actionIndex(ParameterBag $params)
	{
		$page = $this->filterPage();
		$perPage = 10;
		
		$oneCikanRepo = $this->getOneCikanRepo();
		
		$entries = $oneCikanRepo->findOneCikan();
		$entries->limitByPage($page, $perPage);

		$filter = $this->filter('_xfFilter', [
			'text' => 'str',
			'prefix' => 'bool'
		]);
		if (strlen($filter['text']))
		{
			$entries->searchTitle($filter['text'], $filter['prefix']);
		}
		
		$viewParams = [
			'onecikanlar' => $entries->fetch(),
			'total' => $entries->total(),
			'page' => $page,
			'perPage' => $perPage,
			'filter' => $filter['text'],
		];
		return $this->view('XenGenTr\ResimliOneCikanKonular:OneCikan\List', 'xgt_OneCikan_Konular_Liste', $viewParams);
	}
	
	public function actionEdit(ParameterBag $params)
	{
		$thread = $this->assertThreadExists($params->thread_id);
		$onecikan = $this->assertOneCikanExists($params->thread_id);
			
		$viewParams = [
			'thread' => $thread,
			'onecikan' => $onecikan,
		];
		
		return $this->view('XenGenTr\ResimliOneCikanKonular:OneCikan\Edit', 'xgt_OneCikan_Konular_Degistir', $viewParams);
	}
	
	public function actionSave(ParameterBag $params)
	{
		$onecikan = $this->assertOneCikanExists($params->thread_id, 'Thread');
		
		$input = $this->filter('onecikan', 'array');
		$input['onecikan_baslik'] = !empty($input['onecikan_baslik']) ? $input['onecikan_baslik'] : '';
		$input['onecikan_aciklama'] = !empty($input['onecikan_aciklama']) ? $input['onecikan_aciklama'] : '';
		
		$date = $this->filter('date', 'datetime');
		$time = $this->filter('time', 'str');
		list ($hour, $min) = explode(':', $time);
		
		$dateTime = new \DateTime('@'.$date);
		$dateTime->setTimeZone(\XF::language()->getTimeZone());
		$dateTime->setTime($hour, $min);
		$input['onecikan_tarih'] = $dateTime->getTimestamp();
		
		$form = $this->formAction();
		$form->basicEntitySave($onecikan, $input);
		$form->run();
		
		if ($upload = $this->request->getFile('upload', false, false))
		{
			$this->getOneCikanRepo()->setOneCikanFromUpload($onecikan, $upload);
		}
		
		return $this->redirect($this->buildLink('onecikan-konular/onecikanlar'));
	}
	
	public function actionDelete(ParameterBag $params)
	{
		$onecikan = $this->assertOneCikanExists($params->thread_id, 'Thread');

		$plugin = $this->plugin('XF:Delete');
		return $plugin->actionDelete(
			$onecikan,
			$this->buildLink('onecikan-konular/onecikanlar/delete', $onecikan),
			$this->buildLink('onecikan-konular/onecikanlar/edit', $onecikan),
			$this->buildLink('onecikan-konular/onecikanlar'),
			$onecikan->Thread->title
		);
	}
	
	protected function assertOneCikanExists($id, $with = null, $phraseKey = null)
	{
		return $this->assertRecordExists('XenGenTr\ResimliOneCikanKonular:OneCikan', $id, $with, $phraseKey);
	}
	
	protected function assertThreadExists($id, $with = null, $phraseKey = null)
	{
		return $this->assertRecordExists('XF:Thread', $id, $with, $phraseKey);
	}

	protected function getOneCikanRepo()
	{
		return $this->repository('XenGenTr\ResimliOneCikanKonular:OneCikan');
	}
}